AsciiSet

Struct AsciiSet 

pub struct AsciiSet { /* private fields */ }
Represents a set of characters or bytes in the ASCII range.

This is used in percent_encode and utf8_percent_encode. This is similar to percent-encode sets.

Use the add method of an existing set to define a new set. For example:

use percent_encoding::{AsciiSet, CONTROLS};

/// https://url.spec.whatwg.org/#fragment-percent-encode-set
const FRAGMENT: &AsciiSet = &CONTROLS.add(b' ').add(b'"').add(b'<').add(b'>').add(b'`');

Implementations

Source

impl AsciiSet

pub const EMPTY: Self

An empty set.

pub const fn add(&self, byte: u8) -> Self

pub const fn remove(&self, byte: u8) -> Self

pub const fn union(&self, other: Self) -> Self

Return the union of two sets.

pub const fn complement(&self) -> Self

Return the negation of the set.